@@ -10,9 +10,6 @@ from paperfetcher import handsearch
 
 logger = logging.getLogger(__name__)
 
-# Set logging default to DEBUG
-logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-
 ############################################################################
 # CrossrefSearch unit tests
 ############################################################################
@@ -34,7 +31,3 @@ def test_fetch_batch():
     logger.info(data)
     assert(type(data) == dict)
     assert(len(data['items']) == 5)
-
-
-def test_parse_fields():
-    pass
