@@ -11,28 +11,25 @@ from paperfetcher.datastructures import DOIDataset
 
 logger = logging.getLogger(__name__)
 
-# Set logging default to DEBUG
-logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-
 ############################################################################
-# CrossrefSearch unit tests
+# CrossrefBackwardReferenceSearch unit tests
 ############################################################################
 
 
-def test_check_doi_exists():
-    test_1 = snowballsearch.CrossrefSearch._check_doi_exists("10.1021/acs.jpcb.1c02191")
-    test_2 = snowballsearch.CrossrefSearch._check_doi_exists("xx.yy.zz/pqr123")
+def test_crback_check_doi_exists():
+    test_1 = snowballsearch.CrossrefBackwardReferenceSearch._check_doi_exists("10.1021/acs.jpcb.1c02191")
+    test_2 = snowballsearch.CrossrefBackwardReferenceSearch._check_doi_exists("xx.yy.zz/pqr123")
     assert(test_1)
     assert(not test_2)
 
 
-def test_check_doi_has_references():
-    test = snowballsearch.CrossrefSearch._check_doi_has_references("10.1021/acs.jpcb.1c02191")
+def test_crback_check_doi_has_references():
+    test = snowballsearch.CrossrefBackwardReferenceSearch._check_doi_has_references("10.1021/acs.jpcb.1c02191")
     assert(test)
 
 
-def test_from_dataset():
+def test_crback_from_dataset():
     test_ds = DOIDataset(["10.1021/acs.jpcb.1c02191"])
-    test = snowballsearch.CrossrefSearch.from_DOIDataset(test_ds)
+    test = snowballsearch.CrossrefBackwardReferenceSearch.from_DOIDataset(test_ds)
     assert(len(test.search_dois) == 1)
     assert("10.1021/acs.jpcb.1c02191" in test.search_dois)
